@@ -141,17 +141,17 @@ impl<'a> Config<'a> {
 
     /// Get IPv4 replacement value
     pub fn get_ipv4_value(&self) -> &'a str {
-        &self.ipv4
+        self.ipv4
     }
 
     /// Get IPv6 replacement value
     pub fn get_ipv6_value(&self) -> &'a str {
-        &self.ipv6
+        self.ipv6
     }
 
     /// Get string replacement value
     pub fn get_host_value(&self) -> &'a str {
-        &self.host
+        self.host
     }
 
     /// Get `skip` value
@@ -281,15 +281,16 @@ fn replace_remote_address<R: BufRead, W: Write>(
         let bytes_read = reader.read_until(b'\n', &mut buf)?;
         if bytes_read == 0 {
             break;
-        } else {
-            #[allow(clippy::match_wildcard_for_single_variants)]
-            if config.get_trim() {
-                let s = match buf.iter().position(|&x| x != b' ' && x != b'\t') {
-                    Some(s) => s,
-                    _ => 0,
-                };
-                buf.drain(..s);
-            }
+        }
+
+        #[allow(clippy::match_wildcard_for_single_variants)]
+        if config.get_trim() {
+            let s = match buf.iter().position(|&x| x != b' ' && x != b'\t') {
+                Some(s) => s,
+                _ => 0,
+            };
+            buf.drain(..s);
+
             for (i, byte) in buf[..].iter().enumerate() {
                 if *byte == b' ' {
                     if String::from_utf8_lossy(&buf[..i])
@@ -309,7 +310,7 @@ fn replace_remote_address<R: BufRead, W: Write>(
                         // trying to avoid the regex' overhead
                         match &buf[i + 3..i + 6].iter().cmp(b"- [") {
                             Ordering::Equal if config.get_optimize() => {
-                                writer.write_all(&buf[i..])?
+                                writer.write_all(&buf[i..])?;
                             }
                             _ => {
                                 if let Some(time_field) = RE.find_at(&buf, i) {
@@ -402,7 +403,13 @@ pub fn run(config: &Config, ioconfig: &IOConfig) {
                 Err(e) => {
                     eprintln!("Error reading file '{}': {}.", arg.display(), e);
                     if let Some(output) = ioconfig.get_output() {
-                        std::fs::remove_file(Path::new(output)).unwrap();
+                        if let Err(e) = std::fs::remove_file(Path::new(output)) {
+                            eprintln!(
+                                "Counld not remove output file '{}': {}",
+                                output.display(),
+                                e
+                            );
+                        }
                     }
                     process::exit(1);
                 }
@@ -411,7 +418,13 @@ pub fn run(config: &Config, ioconfig: &IOConfig) {
             if let Err(e) = replace_remote_address(config, reader, &mut writer) {
                 eprintln!("Error: {}", e);
                 if let Some(output) = ioconfig.get_output() {
-                    std::fs::remove_file(Path::new(output)).unwrap();
+                    if let Err(e) = std::fs::remove_file(Path::new(output)) {
+                        eprintln!(
+                            "Counld not remove output file '{}': {}",
+                            output.display(),
+                            e
+                        );
+                    }
                 }
                 process::exit(1);
             }
@@ -422,7 +435,13 @@ pub fn run(config: &Config, ioconfig: &IOConfig) {
         if let Err(e) = replace_remote_address(config, reader, &mut writer) {
             eprintln!("Error: {}", e);
             if let Some(output) = ioconfig.get_output() {
-                std::fs::remove_file(Path::new(output)).unwrap();
+                if let Err(e) = std::fs::remove_file(Path::new(output)) {
+                    eprintln!(
+                        "Counld not remove output file '{}': {}",
+                        output.display(),
+                        e
+                    );
+                }
             }
             process::exit(1);
         }
